@@ -217,7 +217,7 @@ class PreparedCandidate:
         self.req = candidate.req
 
         self._metadata_dir: str | None = None
-        self._metadata = self.prepare_metadata()
+        self._metadata: Distribution | None = None
 
     @cached_property
     def ireq(self) -> pip_shims.InstallRequirement:
@@ -328,6 +328,7 @@ class PreparedCandidate:
         build_dir = self._get_wheel_dir()
         if not os.path.exists(build_dir):
             os.makedirs(build_dir)
+        termui.logger.debug("Building wheel for %s", self.ireq.link)
         self.wheel = builder.build(build_dir, metadata_directory=self._metadata_dir)
         return self.wheel
 
@@ -351,7 +352,7 @@ class PreparedCandidate:
                 or ireq.link.is_wheel
                 and not self._wheel_compatible(ireq.link.filename, allow_all)
             ):
-                ireq.link = None
+                ireq.link = self.wheel = None  # reset the incompatible wheel
                 with allow_all_wheels(allow_all):
                     ireq.link = populate_link(finder, ireq, False)
                 if not ireq.link:
@@ -416,6 +417,8 @@ class PreparedCandidate:
 
     @property
     def metadata(self) -> Distribution:
+        if self._metadata is None:
+            self._metadata = self.prepare_metadata()
         return self._metadata
 
     def get_dependencies_from_metadata(self) -> list[str]:
