@@ -162,6 +162,18 @@ def join_list_with(items: list[Any], sep: Any) -> list[Any]:
     return new_items[:-1]
 
 
+original_wheel_supported = PipWheel.supported
+original_support_index_min = PipWheel.support_index_min
+_has_find_most_preferred_tag = (
+    getattr(PipWheel, "find_most_preferred_tag", None) is not None
+)
+
+if _has_find_most_preferred_tag:
+    original_find: Any = PipWheel.find_most_preferred_tag
+else:
+    original_find = None
+
+
 @no_type_check
 @contextmanager
 def allow_all_wheels(enable: bool = True) -> Iterator:
@@ -172,8 +184,6 @@ def allow_all_wheels(enable: bool = True) -> Iterator:
     and set a new one, or else the results from the previous non-patched calls
     will interfere.
     """
-    from pdm.models.pip_shims import PipWheel
-
     if not enable:
         yield
         return
@@ -191,25 +201,14 @@ def allow_all_wheels(enable: bool = True) -> Iterator:
     ) -> int:
         return 0
 
-    has_find_most_preferred_tag = (
-        getattr(PipWheel, "find_most_preferred_tag", None) is not None
-    )
-
-    original_wheel_supported = PipWheel.supported
-    original_support_index_min = PipWheel.support_index_min
-    if has_find_most_preferred_tag:
-        original_find = PipWheel.find_most_preferred_tag
-    else:
-        original_find = None
-
     PipWheel.supported = _wheel_supported
     PipWheel.support_index_min = _wheel_support_index_min
-    if has_find_most_preferred_tag:
+    if _has_find_most_preferred_tag:
         PipWheel.find_most_preferred_tag = _find_most_preferred_tag
     yield
     PipWheel.supported = original_wheel_supported
     PipWheel.support_index_min = original_support_index_min
-    if has_find_most_preferred_tag:
+    if _has_find_most_preferred_tag:
         PipWheel.find_most_preferred_tag = original_find
 
 
