@@ -56,6 +56,7 @@ class LocalFileAdapter(requests.adapters.BaseAdapter):
     ):
         file_path = self.base_path / urlparse(request.url).path.lstrip("/")
         response = requests.models.Response()
+        response.url = request.url
         response.request = request
         if not file_path.exists():
             response.status_code = 404
@@ -77,7 +78,7 @@ class LocalFileAdapter(requests.adapters.BaseAdapter):
 
 
 class MockVersionControl(versioncontrol.VersionControl):
-    def obtain(self, dest, url):
+    def obtain(self, dest, url, verbosity=0):
         url, _ = self.get_url_rev_options(url)
         path = os.path.splitext(os.path.basename(urlparse(str(url)).path))[0]
         mocked_path = FIXTURES / "projects" / path
@@ -121,7 +122,9 @@ class TestRepository(BaseRepository):
         except KeyError:
             raise CandidateInfoNotFound(candidate)
         deps = pypi_data.get("dependencies", [])
-        deps = filter_requirements_with_extras(deps, candidate.req.extras or ())
+        deps = filter_requirements_with_extras(
+            candidate.req.name, deps, candidate.req.extras or ()
+        )
         return deps, pypi_data.get("requires_python", ""), ""
 
     def dependency_generators(self) -> Iterable[Callable[[Candidate], CandidateInfo]]:
@@ -138,7 +141,6 @@ class TestRepository(BaseRepository):
         for version, candidate in self._pypi_data.get(requirement.key, {}).items():
             c = Candidate(
                 requirement,
-                self.environment,
                 name=requirement.project_name,
                 version=version,
             )
@@ -152,10 +154,10 @@ class TestRepository(BaseRepository):
 
 
 class TestProject(Project):
-    def __init__(self, core, root_path, is_global):
+    def __init__(self, core, root_path, is_global, global_config):
         self.root_path = Path(root_path or ".")
         self.GLOBAL_PROJECT = self.root_path / ".pdm-home" / "global-project"
-        super().__init__(core, root_path, is_global)
+        super().__init__(core, root_path, is_global, global_config)
 
 
 class Distribution:
@@ -164,13 +166,10 @@ class Distribution:
         self.link_file = "editable" if editable else None
         self.dependencies = []
         self.metadata = {"Name": key}
-
-    @property
-    def key(self):
-        return self.metadata["Name"]
+        self.name = key
 
     def as_req(self):
-        return parse_requirement(f"{self.key}=={self.version}")
+        return parse_requirement(f"{self.name}=={self.version}")
 
     @property
     def requires(self):
@@ -185,7 +184,7 @@ class MockWorkingSet(collections.abc.MutableMapping):
         self._data = {}
 
     def add_distribution(self, dist):
-        self._data[dist.key] = dist
+        self._data[dist.name] = dist
 
     def __getitem__(self, key):
         return self._data[key]
@@ -217,7 +216,7 @@ def working_set(mocker, repository):
         rv.add_distribution(dist)
 
     def uninstall(dist):
-        del rv[dist.key]
+        del rv[dist.name]
 
     install_manager = mocker.MagicMock()
     install_manager.install.side_effect = install
@@ -250,20 +249,21 @@ def remove_pep582_path_from_pythonpath(pythonpath):
     return os.pathsep.join(paths)
 
 
-@pytest.fixture(scope="session")
+@pytest.fixture()
 def core():
+    old_config_map = Config._config_map.copy()
     main = Core()
     main.project_class = TestProject
-    return main
+    yield main
+    # Restore the config items
+    Config._config_map = old_config_map
 
 
 @pytest.fixture()
 def project_no_init(tmp_path, mocker, core):
     p = core.create_project(tmp_path)
-    mocker.patch("pdm.project.core.Config.HOME_CONFIG", tmp_path)
     mocker.patch("pdm.utils.get_finder", get_local_finder)
     mocker.patch("pdm.models.environment.get_finder", get_local_finder)
-    old_config_map = Config._config_map.copy()
     tmp_path.joinpath("caches").mkdir(parents=True)
     p.global_config["cache_dir"] = tmp_path.joinpath("caches").as_posix()
     do_use(p, getattr(sys, "_base_executable", sys.executable))
@@ -277,8 +277,6 @@ def project_no_init(tmp_path, mocker, core):
         if pythonpath:
             os.environ["PYTHONPATH"] = pythonpath
         yield p
-    # Restore the config items
-    Config._config_map = old_config_map
 
 
 @pytest.fixture()
